@@ -23,6 +23,13 @@ def preview(ctx):
     """Generate previews for the dataset."""
 
 
+@preview.command()
+@click.argument("path")
+@click.pass_context
+def mosaic(ctx, path):
+    """Generate mosaic for each layer."""
+
+
 @preview.command()
 @click.argument("path")
 @click.pass_context
@@ -42,8 +49,9 @@ def _normalized_scale(scale):
 
 @preview.command()
 @click.argument("path")
+@click.option("-g", "--gap", type=int, default=1, help="Gap between faces.")
 @click.pass_context
-def net(ctx, path):
+def net(ctx, path, gap):
     """Generate net of data blocks."""
     try:
         from utoolbox.util.preview import cuboid_net
@@ -87,7 +95,7 @@ def net(ctx, path):
             nets = []
             for channel, c_ds in MultiChannelDatasetIterator(v_ds):
                 array = ds[c_ds]
-                net = cuboid_net(array, scale)
+                net = cuboid_net(array, scale, gap=gap)
                 nets.append(net)
 
             # reshape to TZCYXS
